==> haskell-pipes-http-1.0.6-635-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pipes-http
version:              1.0.6
visibility:           public
id:                   pipes-http-1.0.6-DeyCjZeme4jH9HPR8cw0Mf
key:                  pipes-http-1.0.6-DeyCjZeme4jH9HPR8cw0Mf
license:              BSD-3-Clause
copyright:            2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library

category:             Pipes, Web
abi:                  9e713f2aa46d70a6f539016e8434c5fc
exposed:              True
exposed-modules:      Pipes.HTTP
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pipes-http-1.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pipes-http-1.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pipes-http-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pipes-http
hs-libraries:         HSpipes-http-1.0.6-DeyCjZeme4jH9HPR8cw0Mf
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    http-client-0.7.17-CKsA30YmMYALZuCSdtq8LI
    http-client-tls-0.3.6.4-8dz8Cr1EoJ9CU6gnshIr0Z
    pipes-4.3.16-3jk1Po97sQ3CIxFFtdnL3F

haddock-interfaces:   /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html:         /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-http-1.0.6-638-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes-http.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pipes-http
version:              1.0.6
visibility:           public
id:                   pipes-http-1.0.6-LmlbVTEPfZ0KPjEsoeoaJY
key:                  pipes-http-1.0.6-LmlbVTEPfZ0KPjEsoeoaJY
license:              BSD-3-Clause
copyright:            2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             HTTP client with pipes interface
description:
    @pipes-http@ is a @pipes@ wrapper around the @http-client@ library

category:             Pipes, Web
abi:                  8b565e3acbccf9c53cbe2bf819c92b67
exposed:              True
exposed-modules:      Pipes.HTTP
import-dirs:          /usr/lib/ghc-9.4.8/site-local/pipes-http-1.0.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pipes-http-1.0.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pipes-http-1.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pipes-http
hs-libraries:         HSpipes-http-1.0.6-LmlbVTEPfZ0KPjEsoeoaJY
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    http-client-0.7.17-7ke50M5l2YA8vO0Zwid8PF
    http-client-tls-0.3.6.4-7YkGOrJ46aWAfk291roKAU
    pipes-4.3.16-3jk1Po97sQ3CIxFFtdnL3F

haddock-interfaces:   /usr/share/doc/haskell-pipes-http/html/pipes-http.haddock
haddock-html:         /usr/share/doc/haskell-pipes-http/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
